@@ -99,8 +99,10 @@ pyorbit_load_file(PyObject *self, PyObject *args)
 
     pyorbit_handle_types_and_interfaces(ifaces, types, path);
 
-    //CORBA_free(ifaces);
-    //CORBA_free(types);
+#if 0
+    CORBA_free(ifaces);
+    CORBA_free(types);
+#endif
 
     Py_INCREF(Py_None);
     return Py_None;
@@ -235,66 +237,65 @@ register_corba_types(void)
     pyorbit_register_stub(TC_CORBA_octet, NULL);
     pyorbit_register_stub(TC_CORBA_any, NULL);
     pyorbit_register_stub(TC_CORBA_TypeCode,(PyObject*)&PyCORBA_TypeCode_Type);
-    //pyorbit_register_stub(TC_CORBA_Principal, NULL);
     pyorbit_register_stub(TC_CORBA_Object, (PyObject *)&PyCORBA_Object_Type);
     pyorbit_register_stub(TC_CORBA_string, NULL);
     pyorbit_register_stub(TC_CORBA_wstring, NULL);
 
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ConstructionPolicy);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_Current);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_DomainManager);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_Policy);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_AliasDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ArrayDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_AttributeDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ConstantDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_Contained);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_Container);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_EnumDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ExceptionDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_FixedDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_IDLType);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_InterfaceDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_IRObject);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ModuleDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_NativeDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_OperationDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_PrimitiveDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_Repository);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_SequenceDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_StringDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_StructDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_TypedefDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_UnionDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ValueDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ValueBoxDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ValueMemberDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_WstringDef);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_Identifier);
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ConstructionPolicy); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_Current); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_DomainManager); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_Policy); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_AliasDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ArrayDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_AttributeDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ConstantDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_Contained); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_Container); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_EnumDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ExceptionDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_FixedDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_IDLType); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_InterfaceDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_IRObject); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ModuleDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_NativeDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_OperationDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_PrimitiveDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_Repository); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_SequenceDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_StringDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_StructDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_TypedefDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_UnionDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ValueDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ValueBoxDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ValueMemberDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_WstringDef); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_Identifier); */
     pyorbit_generate_typecode_stubs(TC_CORBA_completion_status);
     pyorbit_generate_typecode_stubs(TC_CORBA_exception_type);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_PolicyType);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_PolicyList);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_PolicyErrorCode);
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_PolicyType); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_PolicyList); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_PolicyErrorCode); */
     pyorbit_generate_typecode_stubs(TC_CORBA_PolicyError);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_DomainManagersList);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ScopedName);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_RepositoryId);
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_DomainManagersList); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ScopedName); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_RepositoryId); */
     pyorbit_generate_typecode_stubs(TC_CORBA_DefinitionKind);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_VersionSpec);
-    // ** pyorbit_generate_typecode_stubs(TC_CORBA_Contained_Description);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_InterfaceDefSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ValueDefSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ContainedSeq);
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_VersionSpec); */
+    /* ** pyorbit_generate_typecode_stubs(TC_CORBA_Contained_Description); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_InterfaceDefSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ValueDefSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ContainedSeq); */
     pyorbit_generate_typecode_stubs(TC_CORBA_StructMember);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_StructMemberSeq);
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_StructMemberSeq); */
     pyorbit_generate_typecode_stubs(TC_CORBA_Initializer);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_InitializerSeq);
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_InitializerSeq); */
     pyorbit_generate_typecode_stubs(TC_CORBA_UnionMember);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_UnionMemberSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_EnumMemberSeq);
-    // ** pyorbit_generate_typecode_stubs(TC_CORBA_Container_Description);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_Container_DescriptionSeq);
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_UnionMemberSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_EnumMemberSeq); */
+    /* ** pyorbit_generate_typecode_stubs(TC_CORBA_Container_Description); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_Container_DescriptionSeq); */
     pyorbit_generate_typecode_stubs(TC_CORBA_PrimitiveKind);
     pyorbit_generate_typecode_stubs(TC_CORBA_ModuleDescription);
     pyorbit_generate_typecode_stubs(TC_CORBA_ConstantDescription);
@@ -305,50 +306,50 @@ register_corba_types(void)
     pyorbit_generate_typecode_stubs(TC_CORBA_OperationMode);
     pyorbit_generate_typecode_stubs(TC_CORBA_ParameterMode);
     pyorbit_generate_typecode_stubs(TC_CORBA_ParameterDescription);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ParDescriptionSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ContextIdentifier);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ContextIdSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ExceptionDefSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ExcDescriptionSeq);
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ParDescriptionSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ContextIdentifier); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ContextIdSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ExceptionDefSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ExcDescriptionSeq); */
     pyorbit_generate_typecode_stubs(TC_CORBA_OperationDescription);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_RepositoryIdSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_OpDescriptionSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_AttrDescriptionSeq);
-    // ** pyorbit_generate_typecode_stubs(TC_CORBA_InterfaceDef_FullInterfaceDescription);
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_RepositoryIdSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_OpDescriptionSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_AttrDescriptionSeq); */
+    /* ** pyorbit_generate_typecode_stubs(TC_CORBA_InterfaceDef_FullInterfaceDescription); */
     pyorbit_generate_typecode_stubs(TC_CORBA_InterfaceDescription);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_Visibility);
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_Visibility); */
     pyorbit_generate_typecode_stubs(TC_CORBA_ValueMember);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ValueMemberSeq);
-    // ** pyorbit_generate_typecode_stubs(TC_CORBA_ValueDef_FullValueDescription);
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ValueMemberSeq); */
+    /* ** pyorbit_generate_typecode_stubs(TC_CORBA_ValueDef_FullValueDescription); */
     pyorbit_generate_typecode_stubs(TC_CORBA_ValueDescription);
     pyorbit_generate_typecode_stubs(TC_CORBA_TCKind);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ValueModifier);
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ValueModifier); */
     pyorbit_generate_typecode_stubs(TC_CORBA_TypeCode_Bounds);
     pyorbit_generate_typecode_stubs(TC_CORBA_TypeCode_BadKind);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_AnySeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_BooleanSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_CharSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_WCharSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_OctetSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ShortSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_UShortSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_LongSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ULongSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_LongLongSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ULongLongSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_FloatSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_DoubleSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_Flags);
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_AnySeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_BooleanSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_CharSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_WCharSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_OctetSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ShortSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_UShortSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_LongSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ULongSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_LongLongSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ULongLongSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_FloatSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_DoubleSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_Flags); */
     pyorbit_generate_typecode_stubs(TC_CORBA_NamedValue);
     pyorbit_generate_typecode_stubs(TC_CORBA_SetOverrideType);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_RequestSeq);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ServiceType);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ServiceOption);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ServiceDetailType);
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_RequestSeq); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ServiceType); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ServiceOption); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ServiceDetailType); */
     pyorbit_generate_typecode_stubs(TC_CORBA_ServiceDetail);
     pyorbit_generate_typecode_stubs(TC_CORBA_ServiceInformation);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ORB_ObjectId);
-    // pyorbit_generate_typecode_stubs(TC_CORBA_ORB_ObjectIdList);
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ORB_ObjectId); */
+    /* pyorbit_generate_typecode_stubs(TC_CORBA_ORB_ObjectIdList); */
     pyorbit_generate_typecode_stubs(TC_CORBA_ORB_InvalidName);
 }
 
